summaryrefslogtreecommitdiffstats
path: root/webapp/stores/post_store.jsx
diff options
context:
space:
mode:
Diffstat (limited to 'webapp/stores/post_store.jsx')
-rw-r--r--webapp/stores/post_store.jsx5
1 files changed, 3 insertions, 2 deletions
diff --git a/webapp/stores/post_store.jsx b/webapp/stores/post_store.jsx
index 17529acb6..7a532fa2e 100644
--- a/webapp/stores/post_store.jsx
+++ b/webapp/stores/post_store.jsx
@@ -454,10 +454,11 @@ class PostStoreClass extends EventEmitter {
for (let i = 0; i < len; i++) {
const post = postList.posts[postList.order[i]];
// don't edit webhook posts or deleted posts
if (post.user_id !== userId ||
(post.props && post.props.from_webhook) ||
- post.state === Constants.POST_DELETED) {
+ post.state === Constants.POST_DELETED ||
+ (post.type && post.type.startsWith(Constants.SYSTEM_MESSAGE_PREFIX))) {
continue;
}
@@ -454,10 +454,11 @@ class PostStoreClass extends EventEmitter {
for (let i = 0; i < len; i++) {
const post = postList.posts[postList.order[i]];
- // don't edit webhook posts or deleted posts
+ // don't edit webhook posts, deleted posts, or system messages
if (post.user_id !== userId ||
(post.props && post.props.from_webhook) ||